==> savane-1.0.3.1.tar.gz: savane/frontend/php/help/bug_admin_field_values_settings.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bug_admin_field_values_settings.php,v 1.6 2004/03/13 18:22:05 yeupou Exp $
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2004      (c) ...
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";

help_header("Bug Administration -  Bug Field Value Settings");

?>

<p>The Bug Tracking System allows you to define and update your
own values for most of the fields you have decided to use (see Field
Usage menu item).


<p>This page shows allows you to update the parameters of a given
value. Information displayed on this page:

<ul type="compact">

<li><b>Value Label</b>: the text label of the value as shown in the select box

<li><b>Rank</b>: allows you to define the order of the field values in
the select box. The smaller values appear first in the select box. We
strongly advise you to leave some space in between 2 rank numbers (e.g
use 100, 200, 300,...) to make future insertion of new values easier.

<br><b>Important remark:</b> if there is a permanent
'None' value defined for this field, the rank number for your own value
must always be greater than the 'None' rank.

<li><b>Status</b>: 
<ul>
<li><i><u>Active</u></i> : this value is visible in your
bug field select box.

<li><i><u>Hidden</u></i> : this value is not visible in your bug
field select box.

<li><i><u>Permanent</u></i> : these values are permanent and cannot be
removed from the list of possible values. They always appear in the
select box.
</ul>
<p><u>Remark</u>: You can decide to activate/hide a value at any time
in the life of the project. When you hide a value it wont show up in
the select box but old bugs already using this value will continue to
display ok.

<li><b>Description</b>: meaning of the value (optional but useful)

</ul>

==> savane-1.0.5a.tar.gz: savane/frontend/php/help/bug_admin_field_values_settings.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: bug_admin_field_values_settings.php,v 1.7 2004/09/22 08:11:50 yeupou Exp $
#  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
#
#  Copyright 2004      (c) ...
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

require "../include/pre.php";

help_header("Bug Administration -  Bug Field Value Settings");

?>

<p>The Bug Tracking System allows you to define and update your
own values for most of the fields you have decided to use (see Field
Usage menu item).


<p>This page shows allows you to update the parameters of a given
value. Information displayed on this page:

<ul type="compact">

<li><b>Value Label</b>: the text label of the value as shown in the select box

<li><b>Rank</b>: allows you to define the order of the field values in
the select box. The smaller values appear first in the select box. We
strongly advise you to leave some space in between 2 rank numbers (e.g
use 100, 200, 300,...) to make future insertion of new values easier.

<br /><b>Important remark:</b> if there is a permanent
'None' value defined for this field, the rank number for your own value
must always be greater than the 'None' rank.

<li><b>Status</b>: 
<ul>
<li><i><u>Active</u></i> : this value is visible in your
bug field select box.

<li><i><u>Hidden</u></i> : this value is not visible in your bug
field select box.

<li><i><u>Permanent</u></i> : these values are permanent and cannot be
removed from the list of possible values. They always appear in the
select box.
</ul>
<p><u>Remark</u>: You can decide to activate/hide a value at any time
in the life of the project. When you hide a value it wont show up in
the select box but old bugs already using this value will continue to
display ok.

<li><b>Description</b>: meaning of the value (optional but useful)

</ul>
